@@ -7,8 +7,10 @@ import glob
 import json
 import subprocess
 import sys
+from pathlib import Path
 
 from pkg_resources import require
+from ruamel.yaml import YAML
 
 from mlx.junit_checker import JUnitChecker
 from mlx.regex_checker import CoverityChecker, DoxyChecker, SphinxChecker, XMLRunnerChecker
@@ -19,24 +21,29 @@ __version__ = require('mlx.warnings')[0].version
 
 class WarningsPlugin:
 
-    def __init__(self, verbose=False, config_file=None):
+    def __init__(self, verbose=False, config_file=None, cq_enabled=False):
         '''
         Function for initializing the parsers
 
         Args:
             verbose (bool): optional - enable verbose logging
-            config_file (str): optional - configuration file with setup
+            config_file (Path): optional - configuration file with setup
+            cq_enabled (bool): optional - enable generation of Code Quality report
         '''
         self.activated_checkers = {}
         self.verbose = verbose
+        self.cq_enabled = cq_enabled
         self.public_checkers = [SphinxChecker(self.verbose), DoxyChecker(self.verbose), JUnitChecker(self.verbose),
                                 XMLRunnerChecker(self.verbose), CoverityChecker(self.verbose),
                                 RobotChecker(self.verbose)]
 
         if config_file:
-            with open(config_file, 'r') as open_file:
-                config = json.load(open_file)
-            self.config_parser_json(config)
+            with open(config_file, 'r', encoding='utf-8') as open_file:
+                if config_file.suffix.lower().startswith('.y'):
+                    config = YAML().load(open_file)
+                else:
+                    config = json.load(open_file)
+            self.config_parser(config)
 
         self.warn_min = 0
         self.warn_max = 0
@@ -50,7 +57,7 @@ class WarningsPlugin:
         Args:
             checker (WarningsChecker): checker object
         '''
-        checker.reset()
+        checker.cq_enabled = self.cq_enabled and checker.name in ('doxygen', 'sphinx', 'xmlrunner')
         self.activated_checkers[checker.name] = checker
 
     def activate_checker_name(self, name):
@@ -169,11 +176,11 @@ class WarningsPlugin:
         '''
         self.printout = printout
 
-    def config_parser_json(self, config):
+    def config_parser(self, config):
         ''' Parsing configuration dict extracted by previously opened JSON file
 
         Args:
-            config (dict): JSON dump of the configuration
+            config (dict): Content of configuration file
         '''
         # activate checker
         for checker in self.public_checkers:
@@ -196,6 +203,19 @@ class WarningsPlugin:
             for checker in self.activated_checkers.values():
                 open_file.write("\n".join(checker.counted_warnings) + "\n")
 
+    def write_code_quality_report(self, out_file):
+        ''' Generates the Code Quality report artifact as a JSON file that implements a subset of the Code Climate spec
+
+        Args:
+            out_file (str): Location for the output file
+        '''
+        results = []
+        for checker in self.activated_checkers.values():
+            results.extend(checker.cq_findings)
+        content = json.dumps(results, indent=4, sort_keys=False)
+        with open(out_file, 'w', encoding='utf-8', newline='\n') as open_file:
+            open_file.write(f"{content}\n")
+
 
 def warnings_wrapper(args):
     parser = argparse.ArgumentParser(prog='mlx-warnings')
@@ -215,12 +235,14 @@ def warnings_wrapper(args):
     group1.add_argument('--exact-warnings', type=int, default=0,
                         help='Exact amount of warnings expected')
     group2 = parser.add_argument_group('Configuration file with options')
-    group2.add_argument('--config', dest='configfile', action='store', required=False,
+    group2.add_argument('--config', dest='configfile', action='store', required=False, type=Path,
                         help='Config file in JSON format provides toggle of checkers and their limits')
     group2.add_argument('--include-sphinx-deprecation', dest='include_sphinx_deprecation', action='store_true',
                         help="Sphinx checker will include warnings matching (RemovedInSphinx\\d+Warning) regex")
     parser.add_argument('-o', '--output',
                         help='Output file that contains all counted warnings')
+    parser.add_argument('-C', '--code-quality',
+                        help='Output Code Quality report artifact for GitLab CI')
     parser.add_argument('-v', '--verbose', dest='verbose', action='store_true')
     parser.add_argument('--command', dest='command', action='store_true',
                         help='Treat program arguments as command to execute to obtain data')
@@ -232,6 +254,7 @@ def warnings_wrapper(args):
                         help='Possible not-used flags from above are considered as command flags')
 
     args = parser.parse_args(args)
+    code_quality_enabled = bool(args.code_quality)
 
     # Read config file
     if args.configfile is not None:
@@ -240,9 +263,9 @@ def warnings_wrapper(args):
         if checker_flags or warning_args:
             print("Configfile cannot be provided with other arguments")
             sys.exit(2)
-        warnings = WarningsPlugin(verbose=args.verbose, config_file=args.configfile)
+        warnings = WarningsPlugin(verbose=args.verbose, config_file=args.configfile, cq_enabled=code_quality_enabled)
     else:
-        warnings = WarningsPlugin(verbose=args.verbose)
+        warnings = WarningsPlugin(verbose=args.verbose, cq_enabled=code_quality_enabled)
         if args.sphinx:
             warnings.activate_checker_name('sphinx')
         if args.doxygen:
@@ -289,6 +312,8 @@ def warnings_wrapper(args):
     warnings.return_count()
     if args.output:
         warnings.write_counted_warnings(args.output)
+    if args.code_quality:
+        warnings.write_code_quality_report(args.code_quality)
     return warnings.return_check_limits()
 
 
