@@ -13,16 +13,15 @@ class WarningsChecker:
             verbose (bool): Enable/disable verbose logging
         '''
         self.verbose = verbose
-        self.reset()
-        self.exclude_patterns = []
-        self.include_patterns = []
-
-    def reset(self):
-        ''' Reset function (resets min, max and counter values) '''
         self.count = 0
         self.warn_min = 0
         self.warn_max = 0
         self._counted_warnings = []
+        self.cq_findings = []
+        self.cq_enabled = False
+        self.cq_default_path = '.gitlab-ci.yml'
+        self.exclude_patterns = []
+        self.include_patterns = []
 
     @property
     def counted_warnings(self):
@@ -153,6 +152,8 @@ class WarningsChecker:
         self.set_maximum(int(config['max']))
         self.set_minimum(int(config['min']))
         self.add_patterns(config.get("exclude"), self.exclude_patterns)
+        if 'cq_default_path' in config:
+            self.cq_default_path = config['cq_default_path']
 
     def _is_excluded(self, content):
         ''' Checks if the specific text must be excluded based on the configured regexes for exclusion and inclusion.
